==> haskell-cassava-0.5.1.0-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.5.1.0
id: cassava-0.5.1.0-6M71ifrl0DVFGQG5W7s4IE
key: cassava-0.5.1.0-6M71ifrl0DVFGQG5W7s4IE
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    @cassava@ is a library for parsing and encoding [RFC 4180](https://tools.ietf.org/html/rfc4180)
    compliant [comma-separated values (CSV)](https://en.wikipedia.org/wiki/Comma-separated_values) data,
    which is a textual line-oriented format commonly used for exchanging tabular data.
    .
    @cassava@'\''s API includes support for
    .
    - Index-based record-conversion
    - Name-based record-conversion
    - Typeclass directed conversion of fields and records
    - Built-in field-conversion instances for standard types
    - Customizable record-conversion instance derivation via GHC generics
    - Low-level [bytestring](https://hackage.haskell.org/package/bytestring) builders (see "Data.Csv.Builder")
    - Incremental decoding and encoding API (see "Data.Csv.Incremental")
    - Streaming API for constant-space decoding (see "Data.Csv.Streaming")
    .
    Moreover, this library is designed to be easy to use; for instance, here'\''s a
    very simple example of encoding CSV data:
    .
    >>> Data.Csv.encode [("John",27),("Jane",28)]
    "John,27\r\nJane,28\r\n"
    .
    Please refer to the documentation in "Data.Csv" and the included [README](#readme) for more usage examples.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
indefinite: False
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
abi: a8240e86df439726b34024693d1d9682
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cassava-0.5.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/cassava-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cassava-0.5.1.0
hs-libraries: HScassava-0.5.1.0-6M71ifrl0DVFGQG5W7s4IE
depends:
    array-0.5.2.0 attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    Only-0.1-K3HSyq2koL8JtFXn0ZkrT6
    text-short-0.1.2-LDEC6SHL7hqIvBv065JaNA
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4=923ea4b48e3ff86a32743bf7d135ea3e
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX=7aedff29b89e83530bb1e2cdf3ff8b50
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             Only-0.1-K3HSyq2koL8JtFXn0ZkrT6=21cb887b2dde313bd9095bf1e74d7359
             text-short-0.1.2-LDEC6SHL7hqIvBv065JaNA=c60749f05f7c58017a6015a8a9263b43
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-0.5.1.0-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.5.1.0
id: cassava-0.5.1.0-GHp8tmFaH0eBO9HJmU8qaS
key: cassava-0.5.1.0-GHp8tmFaH0eBO9HJmU8qaS
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    @cassava@ is a library for parsing and encoding [RFC 4180](https://tools.ietf.org/html/rfc4180)
    compliant [comma-separated values (CSV)](https://en.wikipedia.org/wiki/Comma-separated_values) data,
    which is a textual line-oriented format commonly used for exchanging tabular data.
    .
    @cassava@'\''s API includes support for
    .
    - Index-based record-conversion
    - Name-based record-conversion
    - Typeclass directed conversion of fields and records
    - Built-in field-conversion instances for standard types
    - Customizable record-conversion instance derivation via GHC generics
    - Low-level [bytestring](https://hackage.haskell.org/package/bytestring) builders (see "Data.Csv.Builder")
    - Incremental decoding and encoding API (see "Data.Csv.Incremental")
    - Streaming API for constant-space decoding (see "Data.Csv.Streaming")
    .
    Moreover, this library is designed to be easy to use; for instance, here'\''s a
    very simple example of encoding CSV data:
    .
    >>> Data.Csv.encode [("John",27),("Jane",28)]
    "John,27\r\nJane,28\r\n"
    .
    Please refer to the documentation in "Data.Csv" and the included [README](#readme) for more usage examples.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
indefinite: False
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
abi: 24afb7d11441ce739d0b15d64f678cf0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cassava-0.5.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/cassava-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cassava-0.5.1.0
hs-libraries: HScassava-0.5.1.0-GHp8tmFaH0eBO9HJmU8qaS
depends:
    array-0.5.2.0 attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    Only-0.1-K3HSyq2koL8JtFXn0ZkrT6
    text-short-0.1.2-HEc0SQzOhwl8JyIAWqNgvL
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI=a27ded325e5d5959c97ff2a5817450bc
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             Only-0.1-K3HSyq2koL8JtFXn0ZkrT6=21cb887b2dde313bd9095bf1e74d7359
             text-short-0.1.2-HEc0SQzOhwl8JyIAWqNgvL=7b266e614f7537bc7bca37659022ccf5
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
